---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behaviour:
1. 
2. 
3. 
4. 

**Expected behaviour**
A clear and concise description of what you expected to happen.

**Logs**
Share with us the log of Nawah app showing the issue.

**Version Details (please complete the following information):**
 - OS: 
 - Python: 
 - Nawah CLI: 
 - Nawah framework version: 
 - Nawah app API Level: 
 - Additional Libs: 
